<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Teknisa\CRM\Service\AgrupamentoParceirosService;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\Model\Util\NovoCodigo;

class AgrupamentoParceiroController extends TeknisaCrud {
    protected $dataSourceName = 'agrupamentoParceiros';
    protected $parameterBagColumns = array('NRORG', 'IDTPOPERADOR', 'NRREVENDA', 'IDATIVO', 'CRM_NRORGTRAB');

    protected $entityManager;
    protected $connection;
    protected $newCode;
    protected $environment;
    protected $agrupamentoParceiroService;

    public function __construct ($crudService, $parameterBag, $entityManager, $environment, $newCode, $agrupamentoParceiroService) {
        
        $this->entityManager               = $entityManager;
        $this->connection                  = $entityManager->getConnection();
        $this->environment                 = $environment;
        $this->newCode                     = $newCode;
        $this->agrupamentoParceiroService  = $agrupamentoParceiroService;

        parent::__construct($crudService, $parameterBag);

    }
    

    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            
            $this->dataSourceName = 'agrupamentoParceirosSave';
            
            $parcError = array();
            $resp = false;
            $bloqueio = false; //Define se o save de algum registro ocorrerá ou não
            $parcs = array();
            
            foreach($rows as $key => &$row) {
                if(!$bloqueio) {
                    if($row['__is_new'] == true) {
                        $resp = $this->agrupamentoParceiroService->verifyGroup($row);
                        
                        if(!empty($resp)) {
                            if($resp[1] == 'PPR') {
                                $bloqueio = true;
                                $parcError[] = array('msg' => 'Operação Bloqueada! O parceiro de negócio "'.$row['NMPRINCIPALPARC'].'" já está relacionado ao parceiro "'.$resp[0]['NMPRINCIPALPARC'].'".');
                            } else if($resp[1] == 'PFR') {
                                $parcError[] = array('msg' => 'Operação Bloqueada! O parceiro de negócio "'.$row['NMPRINCIPALPARCREL'].'" já está relacionado ao parceiro "'.$resp[0]['NMPRINCIPALPARC'].'".');
                                unset($rows[$key]);
                            }
                        } else {
                            if(empty($row['NRAGRPARC'])) {
                                $row['NRAGRPARC'] = NovoCodigo::geraCodigo($row['NRORG'], "CRM_AGRUPAMENTOPARCEIRO", 1, 12, false, true);
                            }
                            $parcs[] = $row['NRPARCNEGOCIO_REL'];
                        }
                    }
                }
            }
            
            if(!$bloqueio) {
                if(!empty($rows)) {
                    parent::save($request, $response);
                }
            }
            
            if($bloqueio || !empty($parcError)) {
                if($bloqueio) {
                    $response->addDataSet(new DataSet("PPR", array()));
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('msg', $parcError));
                } else {
                    $response->addDataSet(new DataSet("PFR", array()));
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('msg', $parcError));
                }
            }
            
            $this->dataSourceName = 'agrupamentoParceiros';
            
            if(!empty($parcs)) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('PARCS', $parcs));
            }
            
            $parentError = $response->getError();
            
            if (!empty($parentError)) {
                throw new \Exception($parentError->getMessage(), $parentError->getErrorCode());
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteGroup(Row $row){
        $row = $row->getRow();
        
        $this->agrupamentoParceiroService->executeDeleteGroup($row);
    }
    
    public function agrupamentoEvolSave(Row $row){
        $row = $row->getRow();
        
        $nrcontato = $this->agrupamentoParceiroService->searchNrContato($row);
        
        if(!empty($nrcontato)) {
            $row['NRSEQEVOLCONT'] = NovoCodigo::geraCodigo($row['NRORG'], "NRSEQEVOLCONT", 1, 12, false, true);
            $row['NRCONTATO'] = $nrcontato['NRCONTATO'];
            $row['NRSEQCONTATO'] = $nrcontato['NRSEQCONTATO'];
            
            $this->agrupamentoParceiroService->agrupamentoEvolSave($row);
        }
    }
    
    public function verifyGroupRel(DTO\Request $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        
        $avaible = $this->agrupamentoParceiroService->verifyGroupRel($rows[0]);
        
        if(empty($avaible)) {
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('GROUPREL', array(false)));
        } else {
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('GROUPREL', array($avaible)));
        }
    }
    
}
