<?php
namespace Teknisa\CRM\Service;

use Teknisa\Model\Util\NovoCodigo;
use Teknisa\CRM\Factory\ParceiroNegocioFactory;

class crm00004000LeadSevice {
    
    protected $leadFactory;
    protected $newCode;
    protected $environment;
    protected $parceiroFactory;
    protected $prospectService;
    
    public function __construct ($newCode, $leadFactory, $environment, ParceiroNegocioFactory $parceiroFactory, ger00045000ProspectService $prospectService) {
        $this->leadFactory        = $leadFactory;
        $this->parceiroFactory    = $parceiroFactory;
        $this->prospectService    = $prospectService;
        $this->newCode            = $newCode;
        $this->environment        = $environment;
    }
    
    public function validaLead($row) {
        if(!empty($row['INSCRICAO'])) {
            $paramsVerifyLeadCPNJ = array(
                "INSCRICAO"      => $row["INSCRICAO"],
                "NRORG"          => $row["NRORG"],
                "CRM_NRORGTRAB"  => $row["CRM_NRORGTRAB"],
                "PKVALUE"        => $row["PKVALUE"]
            );
            
            if($row['IDTPIJURCAN'] === 'J') {
                $leads = $this->leadFactory->verifyLeadCNPJ($paramsVerifyLeadCPNJ);
                if(!empty($leads)) {
                    if(isset($row['IDVALIDACNPJ']) && $row['IDVALIDACNPJ'] == 'N') {
                        $leads = $this->leadFactory->verifyLeadExactCNPJ($paramsVerifyLeadCPNJ);
                    }
                }
            } else {
                $leads = $this->leadFactory->verifyLeadInsc($paramsVerifyLeadCPNJ);
            }
        } else {
            $leads = array();
        }
        
        if(empty($leads) && $row["NOME"] != "" && isset($row['IDBLOQNOMESEMELHA']) && $row['IDBLOQNOMESEMELHA'] == 'S'){
            
            $paramsVerifyLeadName = array(
                "NOME"            => $row["NOME"],
                "NRORG"           => $row["NRORG"],
                "CRM_NRORGTRAB"   => $row["CRM_NRORGTRAB"],
                "PKVALUE"         => $row["PKVALUE"]
            );

            $leads = $this->leadFactory->verifyLeadName($paramsVerifyLeadName); 
            if(empty($leads)) {
                $leads = false;
            }
        } else if(empty($leads)) {
            $leads = false;
        }
        
        return $leads;
    }
    
    public function verificaParametrizacaoProspect($row){
        
        $parcOperador   = $row['NRPARCNEGOCIOOPER'];
        $nrorg      = $row['NRORG'];
        
        $limite = $this->leadFactory->getLimiteProspectsPorOperadorParametrizacao($nrorg);
        $quantidadeOperador = $this->leadFactory->getQuantidadeProspectsOperador($parcOperador, $nrorg);
        
        if($quantidadeOperador >= $limite && $limite != 'SEM_LIMITE'){
            $excedeuLimite = true;
        }else{
            $excedeuLimite = false;
        }
        
        $return = array(
                    "EXCEDEULIMITE" => $excedeuLimite,
                    "LIMITE"        => $limite,
                    "QUANTIDADE"    => $quantidadeOperador
                  );
        
        return $return;
    }
    
    public function verificaFilialOper($cdoperevol, $nrorg){
        $paramsVerifyFilial = array(
            "CDOPEREVOL"            => $cdoperevol,
            "NRORG"                 => $nrorg
        );
        try{
            $retorno = $this->leadFactory->verifyFilialOper($paramsVerifyFilial);
            if($retorno[0])$retorno = $retorno[0];
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }
        return $retorno;  
    }
    
    public function validaOperadorRevenda($row){
        
        $parcOperador   = $row['NRPARCPROPRI'];
        $nrorg      = $row['NRORG'];
        
        $limite = $this->leadFactory->getLimiteLeadsPorRevendaParametrizacao($nrorg);
        $quantidadeOperador = $this->leadFactory->getQuantidadeLeadsOperador($parcOperador, $nrorg);
        
        if($quantidadeOperador >= $limite && $limite != 'SEM_LIMITE'){
            $excedeuLimite = true;
        }else{
            $excedeuLimite = false;
        }
        
        $return = array(
                    "EXCEDEULIMITE" => $excedeuLimite,
                    "LIMITE"        => $limite,
                    "QUANTIDADE"    => $quantidadeOperador
                  );
        return $return;
    }
    
    public function prepareInsertLeadEvolutionNextTask($row){

        $row["NRSEQFILACONTA"] = $this->newCode->getCodeByTableName("FILACONTATO", $row["NRORG"]);
        
        $paramsInsertLeadEvolNextTask = array(
            "DSFILACONTATO"             => $row["DSFILACONTATO"],
            "DTPLANFILACONTA"           => $row["DTPLANFILACONTA"],
            "CDOPERREAL"                => $row["CDOPERREAL"],
            "NRSEQFILACONTA"            => $row["NRSEQFILACONTA"],
            "NRORG"                     => $row["NRORG"],
            "CRM_NRORGTRAB"             => empty($row["CRM_NRORGTRAB"]) ? $row["NRORG"] : $row["CRM_NRORGTRAB"],
            "NRORGINCLUSAO"             => $row["NRORG"],
            "CDOPERINCLUSAO"            => $row["CDOPERREAL"],
            "NRPARCNEGOCIO"             => $row["NRPARCNEGOCIO"],
            "NRCONTATO"                 => $row["NRSEQCONTATO"],
            "NRPRIORFILACONT"           => !empty($row["NRPRIORFILACONT"]) ? $row["NRPRIORFILACONT"] : 2,
            "NRSEQCONTATO"              => $row["NRSEQCONTATO"],
            "NRSEQCLASSIFICATAREFA"     => $row["NRSEQCLASSIFICATAREFA"],
            "NRSEQINTERLOCUTOR"         => empty($row['NRSEQINTERLOCUTOR']) ? '' : $row['NRSEQINTERLOCUTOR'],
            "DSEMAILTAREFA"             => empty($row['EMAILINTERLOC']) ? '' : $row['EMAILINTERLOC'],
            "DSTELEFONETAREFA"          => empty($row['NRTELEFONE1']) ? '' : $row['NRTELEFONE1'],
        );
        
        $this->leadFactory->insertLeadEvolNextTask($paramsInsertLeadEvolNextTask);
        
        return $row["NRSEQFILACONTA"];
        
    }
    
    public function callForSetTaskEndDate($row){
        
        $paramsSetTaskEndDate = array(
            
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"]
            
        );
        
        $this->leadFactory->requestForSetTaskEndDate($paramsSetTaskEndDate);
        
    }
    
    public function callForDeactivateLeadTask($row){
        
        $paramsDeactivateTask = array(
            
            "NRSEQFILACONTA"        => $row["NRSEQFILACONTA"]
            
        );
        
        $this->leadFactory->requestForDeactivateLeadTask($paramsDeactivateTask);
        
    }
    
    public function callForInsertProspectInterlocutor($paramsInsertInterlocutor){
        
        $this->leadFactory->requestForInsertProspectInterlocutor($paramsInsertInterlocutor);
        
    }
    
    public function callToSetLeadIdAtivo($updateParams){
        
        $this->leadFactory->requestToSetLeadIdAtivo($updateParams);
        
    }
    
    public function callToInsertProspectToResale($paramsInsert){
        
        $paramsInsert["NRPROSPREVENDA"] = NovoCodigo::geraCodigo($paramsInsert["NRORG"], "CRM_PROSPREVENDA", 1, 10, false, false);
        
        $this->leadFactory->requestToInsertProspectToResale($paramsInsert);
        
    }
    
    public function callToUpdateLeadPartnership($insertParams){
        $nrorg = $this->environment->getNrorgTrab();
        $nrParceria = NovoCodigo::geraCodigo($nrorg, "PARCERIA", 1, 10, false, true);
        $operador = $this->environment->getCdOperador();
        
        $params = array(
            "NRORG"         => $nrorg,
            "NRPARCERIA"    => $nrParceria,
            "CDOPERADOR"    => $operador,
            "NRPARCNEGOCIO" => $insertParams['NRPARCNEGOCIO']
        );
        
        $this->leadFactory->requestToUpdateLeadPartnership($params);
    }
    
    public function callToGetLeadPartnershipNumber($selectParams){
        
        $partnershipNumber = $this->leadFactory->requestToGetLeadPartnershipNumber($selectParams);
        return $partnershipNumber;
        
    }
    
    public function callToEditLeadResponsibleOperator($updateParams){
        $this->leadFactory->requestToEditLeadResponsibleOperator($updateParams);
    }
    
    public function insertEnderecoParc($insertParams){
        $this->leadFactory->insertEnderecoParc($insertParams);
    }
    
    public function getEnderecoparc($nrParcnegocio, $nrOrg){
        
        $nrEnderecoparc = $this->leadFactory->selectEnderecoparc($nrParcnegocio, $nrOrg);
        return empty($nrEnderecoparc) ? '' : $nrEnderecoparc[0]['NRENDERECOPARC'];
        
    }
    
    public function updateEnderecoParc($updateParams) {
        $this->leadFactory->updateEnderecoParc($updateParams);
    }
    
    public function getComunicaparc($cdcomunicaparc, $cdformacomu, $parcnegocio, $nrorg) {
        
        $paramsGetNrparcEstrutura = array(
            "CDCOMUNICAPARC"        => $cdcomunicaparc,
            "CDFORMACOMU"           => join($cdformacomu, ','),   
            "NRPARCNEGOCIO"         => $parcnegocio,
            "NRORG"                 => $nrorg
        );
        try{
            $retorno = $this->leadFactory->getComunicaparc($paramsGetNrparcEstrutura);
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }
        return $retorno;    
        
    }
    
    public function getTelPrinc($parcnegocio, $nrorg) {
        
        $paramsGetNrparcEstrutura = array(
            "CDFORMACOMU"           => "01",   
            "NRPARCNEGOCIO"         => $parcnegocio,
            "NRORG"                 => $nrorg
        );
        try{
            $retorno = $this->leadFactory->getTelPrinc($paramsGetNrparcEstrutura);
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }
        return $retorno;    
        
    }
    
    public function updateTelPrinc($cdcomunicaparc, $parcnegocio, $nrorg) {
        
        $paramsGetNrparcEstrutura = array(
            "CDCOMUNICAPARC"        => $cdcomunicaparc,   
            "NRPARCNEGOCIO"         => $parcnegocio,
            "NRORG"                 => $nrorg
        );
        try{
            $retorno = $this->leadFactory->updateTelPrinc($paramsGetNrparcEstrutura);
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }
        return $retorno;    
        
    }
    
    public function insertParcnegocio($paramsInsert, $parcCriado) {
        try {
            if(!$parcCriado) {
                $this->leadFactory->insertParcnegocio($paramsInsert);
            }
            
            $retorno = $this->leadFactory->insertStatusParc($paramsInsert);
            
            return $retorno;
        } catch(\Exception $e) {
            throw $e;
        };
    }
    
    public function getParcnegocio($parcnegocio, $nrorg) {
        try{
            $paramsGetNrparcEstrutura = array(
                "NRPARCNEGOCIO"         => $parcnegocio,
                "NRORG"                 => $nrorg
            );
        
            $retorno = $this->leadFactory->getParcnegocio($paramsGetNrparcEstrutura);
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }
        return $retorno;    
        
    }
    
    public function insertCandidato($paramsInsert){
        try{
            $retorno = $this->leadFactory->insertCandidato($paramsInsert);
            return $retorno;
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }   
        
    }
    
    public function getCandidato($nrcandidato, $nrorg){
        
        $paramsGetNrparcEstrutura = array(
            "NRCANDIDATO"           => $nrcandidato,
            "NRORG"                 => $nrorg
        );
        try{
            $retorno = $this->leadFactory->getCandidato($paramsGetNrparcEstrutura);
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }
        return $retorno;    
        
    }
    
    public function insertComunicaparc($paramsInsert){
        
        try{
            $retorno = $this->leadFactory->insertComunicaparc($paramsInsert);
            return $retorno;
        }catch(\Exception $retorno){
            return $retorno->getMessage();
        }   
        
    }
    
    public function saveDtnascifundparc($update){
        $this->leadFactory->saveDtnascifundparc($update);
    }
    
    public function newInterlocutor($row){
         $paramsNewInterlocutor = array(
            "NRSEQINTERLOCUTOR" => intval($row["NRSEQINTERLOCUTOR"]),
            "NMINTERLOCUTOR"    => $row["NMINTERLOCUTOR"],
            "EMAILINTERLOC"     => $row["EMAILINTERLOC"],
            "NRTELEFONE1"       => $row["NRTELEFONE1"],
            "NRPARCNEGOCIO"     => intval($row["NRPARCNEGOCIO"]),
            "NRORG"             => $row["NRORG"],
            "IDATIVO"           => 'S'
        );
        
        $this->leadFactory->insertNewInterlocutor($paramsNewInterlocutor); 
    }
    
    public function verifyExistentPartnership($nrparcnegocio, $cdtipoparceria, $nrorg) {
        return $this->leadFactory->verifyExistentPartnership($nrparcnegocio, $cdtipoparceria, $nrorg); 
    }
    
    public function verifyExistentProspect($row) {
        $nrparcnegocio = $row['NRPARCNEGOCIO'];
        $nrorg = $row['NRORG'];
        return $this->leadFactory->verifyExistentProspect($nrparcnegocio, $nrorg);
    }
    
    public function verificaParceiro($params) {
        return $this->leadFactory->verificaParceiro($params);
    }
    
    public function verificaProspect($nrparcnegocio, $nrorg) {
        return $this->leadFactory->verificaProspect($nrparcnegocio, $nrorg);
    }
    
    public function updateStatusProsp($row) {
        $this->leadFactory->updateStatusProsp($row);
    }
    
    public function buscarDadosParc($nrparcnegocio, $nrorg) {
        $this->leadFactory->buscarDadosParc($nrparcnegocio, $nrorg);
    }
    
    public function getCdOperador($nrparcnegocio) {
        return $this->parceiroFactory->getCdOperador($nrparcnegocio);
    }
    
    public function prepareSelectProspectContact($nrparcnegocio) {
        return $this->prospectService->prepareSelectProspectContact($nrparcnegocio);
    }
    
    public function returnParcAddress($nrparcnegocio) {
        return $this->prospectService->returnParcAddress($nrparcnegocio);
    }
    
    public function searchForParc($row) {
        return $this->leadFactory->searchForParc($row);
    }
    
    public function insertStatusParc($row) {
        $params = [];
        if($row['PARCORIGINAL'] !== $row['NRPARCNEGOCIO']) {
            $params = array(
                "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
                "NRPARCRESP"            => $row["NRPARCRESP"],
                "CDOPERRESP"            => $row["CDOPERRESPONSAVEL"],
                "CDTIPOPARCPRINCIPAL"   => $row["CDTIPOPARCEIRO"],
                "NRORG"                 => $row["NRORG"],
                "CRM_NRORGTRAB"         => $row["CRM_NRORGTRAB"],
                "IDATIVO"               => $row["IDATIVO"],
                "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
                "IDSTATUS"              => $row["IDSTATUSCAN"]
            );
            
        }
        
        $this->leadFactory->insertStatusParc($row, $params);
    }
    
    public function fundeParceiro($row) {
        $this->leadFactory->fundeParceiro($row);
    }
    
    public function desativarStatusParc($row) {
        $this->leadFactory->desativarStatusParc($row);
    }
    
    public function parcRevalidation($nrorg, $nrparcnegocio) {
        $params = array(
            "NRORG" => $nrorg,
            "NRPARCNEGOCIO" => $nrparcnegocio
        );
        return $this->leadFactory->parcRevalidation($params);
    }
}
?>