/* global angular*/
var ZeedhiDirectives = angular.module("ZeedhiDirectives");

ZeedhiDirectives.directive('zhCreateFile', function(ScreenService, templateManager, restEngine, ZhKeyboardService, ShortcutDeveloperService, DTMessages){
	return {
		link: function($scope, $element, $attributes, $controller){
			var createFile = false;
			var defaultContainer;
			var WIDGET_NAME = "widgetToNewFile";

			function getActiveJsonPath(){
				var defaultPath = $scope.DevToolsCtrl.getActiveTreeItem();
				defaultPath = defaultPath._indexPath;
				defaultPath = defaultPath.slice(0, defaultPath.lastIndexOf('/') + 1).replace(".","");
				return defaultPath;
			}

			function setPathCreateFile(){
				$scope.widget.getField('pathCreateFile').value(getActiveJsonPath());
			}

			function setDefaultContainer(){
				var jsonLocation = templateManager.getDocsUrl('defaultJsonValue.json');
				restEngine.requestMetaData(jsonLocation).then(function(data) {
					defaultContainer = JSON.stringify(data.data[0].container, null, '\t');
				});
			}

			function getFileName(widget){
				var fileName = widget.getField('nameCreateFile').value() || "";
				fileName = fileName.trim();
				var isJsonName = fileName.lastIndexOf(".") == fileName.toLowerCase().indexOf(".json");
				fileName = isJsonName && (fileName.indexOf(".") > 0) ? fileName : "";
				if(fileName === ""){
					ScreenService.notificationMessage(DTMessages.FILE_INVALID_NAME, 'error');
				}
				return fileName;
			}

			function getLocalPath(widget){
				var localPath = widget.getField('pathCreateFile').value();
				if(localPath){
					localPath = localPath.trim();
					localPath.replace('\\', '/');
					if(localPath[0] != '/'){
						localPath = '/'+ localPath;
					}
					if(localPath[localPath.length -1] != '/'){
						localPath += '/';
					}
				} else {
					ScreenService.notificationMessage(DTMessages.FILE_INVALID_PATH, 'error');
				}
				return localPath;
			}

			function hideCreateFile(){
				createFile = false;
			}
			$scope.hideCreateFile = hideCreateFile;

			$scope.isToCreateFile = function(){
				return createFile && $scope.inJsonMode();
			};

			$scope.createNewFile = function(){
				var localPath = getLocalPath($scope.widget);
				if(localPath){
					var fileName = getFileName($scope.widget);
					if(fileName){
						var pathToCreate = localPath + fileName;
						var obj = {
							pathToCreate: pathToCreate,
							fileName: fileName,
							defaultContainer: defaultContainer
						};
						$scope.DevToolsCtrl.newFile(obj);
						createFile = false;
					}
				}
			};

			function onCreateFile(){
				createFile = !$scope.inJsonMode() ? false : !createFile;
				return false;
			}
			$scope.onCreateFile = onCreateFile;
			ZhKeyboardService.bind('mod+b', onCreateFile);

			$scope.$watch(
				function(){
					return $scope.isToCreateFile();
				}, function(){
					$scope.DevToolsCtrl.changeHeightOfCodeEditor();
					if(createFile){
						$scope.DevToolsCtrl.openShortcutWidget(WIDGET_NAME);
						setPathCreateFile();
					}
				}
			);

			function buildCreateFileWidget(){
				var FIELDS_CONFIG = {
					pathCreateFile: {
						class: "05 zh-dvtools",
						template: "field/text-edit.html",
						placeholder: 'path',
						events : [{
							"name": "FieldOnKeyup",
							"code": "DevToolsController.createNewFile(args.e.keyCode);",
							"id": (+new Date())
						}]
					},
					nameCreateFile: {
						class: "05 zh-dvtools",
						template: "field/text-edit.html",
						focused: true,

						placeholder: 'fileName.json',
						events : [{
							"name": "FieldOnKeyup",
							"code": "DevToolsController.createNewFile(args.e.keyCode);",
							"id": (+new Date())
						}]
					},
					confirmCreateFile: {
						class: "01 zh-dvtools",
						template: "field/button.html",
						label: "✓",
						events : [{
							"name":"FieldOnClick",
							"code": "DevToolsController.createNewFile();",
							"id": (+new Date())
						}]
					},
					hideCreateFile: {
						class: "01 zh-dvtools",
						template: "field/button.html",
						label: "✗",
						events : [{
							"name":"FieldOnClick",
							"code": "DevToolsController.hideCreateFile(args);",
							"id": (+new Date())
						}]
					}
				};
				ShortcutDeveloperService.createWidgetAndContainer(WIDGET_NAME, FIELDS_CONFIG, hideCreateFile);
			}
			buildCreateFileWidget();
			setDefaultContainer();
		}
	};
});
